# @HEADER
# ************************************************************************
#
#            TriBITS: Tribal Build, Integrate, and Test System
#                    Copyright 2013 Sandia Corporation
#
#
# Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
# the U.S. Government retains certain rights in this software.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
#
# 1. Redistributions of source code must retain the above copyright
# notice, this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright
# notice, this list of conditions and the following disclaimer in the
# documentation and/or other materials provided with the distribution.
#
# 3. Neither the name of the Corporation nor the names of the
# contributors may be used to endorse or promote products derived from
# this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY SANDIA CORPORATION "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL SANDIA CORPORATION OR THE
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
# ************************************************************************
# @HEADER

##############################################################################
#
# CMake variable for use by SEACASProj clients. 
#
# Do not edit: This file was generated automatically by CMake.
#
##############################################################################

#
# Ensure CMAKE_CURRENT_LIST_DIR is usable.
#

# Include guard
if (SEACASProj_CONFIG_INCLUDED)
  return()
endif()
set(SEACASProj_CONFIG_INCLUDED TRUE)

# Make sure CMAKE_CURRENT_LIST_DIR is usable
if (NOT DEFINED CMAKE_CURRENT_LIST_DIR)
  get_filename_component(_THIS_SCRIPT_PATH ${CMAKE_CURRENT_LIST_FILE} PATH)
  set(CMAKE_CURRENT_LIST_DIR ${_THIS_SCRIPT_PATH})
endif()


## ---------------------------------------------------------------------------
## Compilers used by SEACASProj build
## ---------------------------------------------------------------------------

set(SEACASProj_CXX_COMPILER "${_IMPORT_PREFIX}/bin/c++.exe")

set(SEACASProj_C_COMPILER "${_IMPORT_PREFIX}/bin/cc.exe")

set(SEACASProj_Fortran_COMPILER "gfortran")

## ---------------------------------------------------------------------------
## Compiler flags used by SEACASProj build
## ---------------------------------------------------------------------------

set(SEACASProj_CMAKE_BUILD_TYPE "Release")

set(SEACASProj_CXX_COMPILER_FLAGS [[-Wall -Wunused -pedantic ]])

set(SEACASProj_C_COMPILER_FLAGS [[-Wall -Wunused -pedantic -std=c11 ]])

set(SEACASProj_Fortran_COMPILER_FLAGS [[   ]])

## Extra link flags (e.g., specification of fortran libraries)
set(SEACASProj_EXTRA_LD_FLAGS [[-lpthread]])

## This is the command-line entry used for setting rpaths. In a build
## with static libraries it will be empty. 
set(SEACASProj_SHARED_LIB_RPATH_COMMAND "${_IMPORT_PREFIX}/lib")
set(SEACASProj_BUILD_SHARED_LIBS "YES")

set(SEACASProj_LINKER ${_IMPORT_PREFIX}/bin/ld.lld.exe)
set(SEACASProj_AR ${_IMPORT_PREFIX}/bin/llvm-ar.exe)


## ---------------------------------------------------------------------------
## Set library specifications and paths 
## ---------------------------------------------------------------------------

## The project version number
set(SEACASProj_VERSION "2.0")

# For best practices in handling of components, see
# <http://www.cmake.org/cmake/help/v3.2/manual/cmake-developer.7.html#find-modules>.
#
# If components were requested, include only those. If not, include all of
# Trilinos.
if (SEACASProj_FIND_COMPONENTS)
  set(COMPONENTS_LIST ${SEACASProj_FIND_COMPONENTS})
else()
  set(COMPONENTS_LIST SEACAS;SEACASSlice;SEACASNemspread;SEACASNemslice;SEACASZellij;SEACASNas2exo;SEACASMat2exo;SEACASExo_format;SEACASExomatlab;SEACASExodiff;SEACASExo2mat;SEACASCpup;SEACASEpu;SEACASEjoin;SEACASConjoin;SEACASAprepro;SEACASSuplibCpp;SEACASSuplibC;SEACASAprepro_lib;SEACASChaco;SEACASIoss;SEACASNemesis;SEACASExodus;Zoltan)
endif()

# Initialize SEACASProj_FOUND with true, and set it to FALSE if any of
# the required components wasn't found.
set(SEACASProj_FOUND TRUE)
foreach(comp ${COMPONENTS_LIST})
  set(
    INCLUDE_FILE
    ${CMAKE_CURRENT_LIST_DIR}/../${comp}/${comp}Config.cmake
    )
 if (EXISTS ${INCLUDE_FILE})
   # Set SEACASProj_<component>_FOUND.
   set(SEACASProj_${comp}_FOUND TRUE)
   # Include the package file.
   include(${INCLUDE_FILE})
   # Add variables to lists.
   list(APPEND SEACASProj_INCLUDE_DIRS ${${comp}_INCLUDE_DIRS})
   list(APPEND SEACASProj_LIBRARY_DIRS ${${comp}_LIBRARY_DIRS})
   list(APPEND SEACASProj_LIBRARIES ${${comp}_LIBRARIES})
   list(APPEND SEACASProj_TPL_INCLUDE_DIRS ${${comp}_TPL_INCLUDE_DIRS})
   list(APPEND SEACASProj_TPL_LIBRARY_DIRS ${${comp}_TPL_LIBRARY_DIRS})
   list(APPEND SEACASProj_TPL_LIBRARIES ${${comp}_TPL_LIBRARIES})
 else()
   # Set SEACASProj_<component>_FOUND to FALSE.
   set(SEACASProj_${comp}_FOUND FALSE)
   # Set SEACASProj_FOUND to FALSE if component is not optional.
   if(SEACASProj_FIND_REQUIRED_${comp})
     set(SEACASProj_FOUND FALSE)
   endif()
 endif()
endforeach()

# Resolve absolute paths and remove duplicate paths
# for LIBRARY_DIRS and INCLUDE_DIRS
# This reduces stress on regular expressions later
set(short_dirs)
foreach(dir ${SEACASProj_INCLUDE_DIRS})
  get_filename_component(dir_abs ${dir} ABSOLUTE)
  list(APPEND short_dirs ${dir_abs})
endforeach()
list(REMOVE_DUPLICATES short_dirs)
set(SEACASProj_INCLUDE_DIRS ${short_dirs})

set(short_dirs)
foreach(dir ${SEACASProj_LIBRARY_DIRS})
  get_filename_component(dir_abs ${dir} ABSOLUTE)
  list(APPEND short_dirs ${dir_abs})
endforeach()
list(REMOVE_DUPLICATES short_dirs)
set(SEACASProj_LIBRARY_DIRS ${short_dirs})

# Remove duplicates in SEACASProj_LIBRARIES
list(REVERSE SEACASProj_LIBRARIES)
list(REMOVE_DUPLICATES SEACASProj_LIBRARIES)
list(REVERSE SEACASProj_LIBRARIES)

# Remove duplicates in SEACASProj_TPL_INCLUDE_DIRS
if (SEACASProj_TPL_INCLUDE_DIRS)
  list(REMOVE_DUPLICATES SEACASProj_TPL_INCLUDE_DIRS)
endif()

# NOTE: It is *NOT* safe to try to remove duplicate in
# SEACASProj_TPL_LIBRARIES because these can be specified as -L, -l, etc.
# Actaully, we should think about that.

## ---------------------------------------------------------------------------
## MPI specific variables
##   These variables are provided to make it easier to get the mpi libraries
##   and includes on systems that do not use the mpi wrappers for compiling
## ---------------------------------------------------------------------------

set(SEACASProj_INSTALL_DIR "${_IMPORT_PREFIX}")
set(SEACASProj_MPI_LIBRARIES "")
set(SEACASProj_MPI_LIBRARY_DIRS "")
set(SEACASProj_MPI_INCLUDE_DIRS "")
set(SEACASProj_MPI_EXEC "")
set(SEACASProj_MPI_EXEC_PRE_NUMPROCS_FLAGS "")
set(SEACASProj_MPI_EXEC_MAX_NUMPROCS "")
set(SEACASProj_MPI_EXEC_POST_NUMPROCS_FLAGS "")
set(SEACASProj_MPI_EXEC_NUMPROCS_FLAG "")

## ---------------------------------------------------------------------------
## Compiler vendor identifications
## ---------------------------------------------------------------------------
set(SEACASProj_SYSTEM_NAME "Windows")
set(SEACASProj_CXX_COMPILER_ID "Clang")
set(SEACASProj_C_COMPILER_ID "Clang")
set(SEACASProj_Fortran_COMPILER_ID "")
set(SEACASProj_Fortran_IMPLICIT_LINK_LIBRARIES "")

## ---------------------------------------------------------------------------
## Set useful general variables 
## ---------------------------------------------------------------------------

## The packages enabled for this project
set(SEACASProj_PACKAGE_LIST "SEACAS;SEACASSlice;SEACASNemspread;SEACASNemslice;SEACASZellij;SEACASNas2exo;SEACASMat2exo;SEACASExo_format;SEACASExomatlab;SEACASExodiff;SEACASExo2mat;SEACASCpup;SEACASEpu;SEACASEjoin;SEACASConjoin;SEACASAprepro;SEACASSuplibCpp;SEACASSuplibC;SEACASAprepro_lib;SEACASChaco;SEACASIoss;SEACASNemesis;SEACASExodus;Zoltan")

## The TPLs enabled for this project
set(SEACASProj_TPL_LIST "fmt;Matio;METIS;Netcdf")
